@@ -1,17 +1,15 @@
-<?PHP
+<?php
 
 namespace controllers;
 
 /**
  * Controller for item handling
  *
- * @package    controllers
  * @copyright  Copyright (c) Tobias Zeising (http://www.aditu.de)
- * @license    GPLv3 (http://www.gnu.org/licenses/gpl-3.0.html)
+ * @license    GPLv3 (https://www.gnu.org/licenses/gpl-3.0.html)
  * @author     Tobias Zeising <tobias.zeising@aditu.de>
  */
 class Items extends BaseController {
-
     /**
      * mark items as read. Allows one id or an array of ids
      * json
@@ -21,28 +19,28 @@ class Items extends BaseController {
     public function mark() {
         $this->needsLoggedIn();
 
-        if(\F3::get('PARAMS["item"]')!=null)
+        if (\F3::get('PARAMS["item"]') != null) {
             $lastid = \F3::get('PARAMS["item"]');
-        else if(isset($_POST['ids'])) {
+        } elseif (isset($_POST['ids'])) {
             $lastid = $_POST['ids'];
         }
 
         $itemDao = new \daos\Items();
 
         // validate id or ids
-        if (!$itemDao->isValid('id', $lastid))
+        if (!$itemDao->isValid('id', $lastid)) {
             $this->view->error('invalid id');
+        }
 
         $itemDao->mark($lastid);
 
-        $return = array(
+        $return = [
             'success' => true
-        );
+        ];
 
         $this->view->jsonSuccess($return);
     }
 
-
     /**
      * mark item as unread
      * json
@@ -56,17 +54,17 @@ class Items extends BaseController {
 
         $itemDao = new \daos\Items();
 
-        if (!$itemDao->isValid('id', $lastid))
+        if (!$itemDao->isValid('id', $lastid)) {
             $this->view->error('invalid id');
+        }
 
         $itemDao->unmark($lastid);
 
-        $this->view->jsonSuccess(array(
+        $this->view->jsonSuccess([
             'success' => true
-        ));
+        ]);
     }
 
-
     /**
      * starr item
      * json
@@ -80,16 +78,16 @@ class Items extends BaseController {
 
         $itemDao = new \daos\Items();
 
-        if (!$itemDao->isValid('id', $id))
+        if (!$itemDao->isValid('id', $id)) {
             $this->view->error('invalid id');
+        }
 
         $itemDao->starr($id);
-        $this->view->jsonSuccess(array(
+        $this->view->jsonSuccess([
             'success' => true
-        ));
+        ]);
     }
 
-
     /**
      * unstarr item
      * json
@@ -103,16 +101,16 @@ class Items extends BaseController {
 
         $itemDao = new \daos\Items();
 
-        if (!$itemDao->isValid('id', $id))
+        if (!$itemDao->isValid('id', $id)) {
             $this->view->error('invalid id');
+        }
 
         $itemDao->unstarr($id);
-        $this->view->jsonSuccess(array(
+        $this->view->jsonSuccess([
             'success' => true
-        ));
+        ]);
     }
 
-
     /**
      * returns items as json string
      * json
@@ -123,9 +121,10 @@ class Items extends BaseController {
         $this->needsLoggedInOrPublicMode();
 
         // parse params
-        $options = array();
-        if(count($_GET)>0)
+        $options = [];
+        if (count($_GET) > 0) {
             $options = $_GET;
+        }
 
         // get items
         $itemDao = new \daos\Items();
@@ -134,7 +133,6 @@ class Items extends BaseController {
         $this->view->jsonSuccess($items);
     }
 
-
     /**
      * returns current basic stats
      * json
@@ -146,25 +144,22 @@ class Items extends BaseController {
 
         $itemsDao = new \daos\Items();
         $stats = $itemsDao->stats();
-	$stats['unread'] -= $itemsDao->numberOfUnreadForTag("#");
 
-	$tagsDao = new \daos\Tags();
-	$tags = $tagsDao->getWithUnread();
-        if ($tagsDao->hasTag("#")) {
-            foreach ($tags as $tag) {
-                if (strcmp($tag["tag"], "#") !== 0) {
-                    continue;
-                }
-                $stats['unread'] -= $tag["unread"];
+        $tagsDao = new \daos\Tags();
+        $tags = $tagsDao->getWithUnread();
+
+        foreach ($tags as $tag) {
+            if (strpos($tag['tag'], '#') !== 0) {
+                continue;
             }
+            $stats['unread'] -= $tag['unread'];
         }
 
-        if( array_key_exists('tags', $_GET) && $_GET['tags'] == 'true' ) {
-            $tagsDao = new \daos\Tags();
+        if (array_key_exists('tags', $_GET) && $_GET['tags'] == 'true') {
             $tagsController = new \controllers\Tags();
-            $stats['tagshtml'] = $tagsController->renderTags($tagsDao->getWithUnread());
+            $stats['tagshtml'] = $tagsController->renderTags($tags);
         }
-        if( array_key_exists('sources', $_GET) && $_GET['sources'] == 'true' ) {
+        if (array_key_exists('sources', $_GET) && $_GET['sources'] == 'true') {
             $sourcesDao = new \daos\Sources();
             $sourcesController = new \controllers\Sources();
             $stats['sourceshtml'] = $sourcesController->renderSources($sourcesDao->getWithUnread());
@@ -172,4 +167,48 @@ class Items extends BaseController {
 
         $this->view->jsonSuccess($stats);
     }
+
+    /**
+     * returns updated database info (stats, item statuses)
+     * json
+     *
+     * @return void
+     */
+    public function sync() {
+        $this->needsLoggedInOrPublicMode();
+
+        if (!array_key_exists('since', $_GET)) {
+            $this->view->jsonError(['sync' => 'missing since argument']);
+        }
+
+        $since = new \DateTime($_GET['since']);
+
+        $itemsDao = new \daos\Items();
+        $last_update = new \DateTime($itemsDao->lastUpdate());
+
+        $sync = [
+            'last_update' => $last_update->format(\DateTime::ATOM),
+        ];
+
+        if ($last_update > $since) {
+            $sync['stats'] = $itemsDao->stats();
+
+            if (array_key_exists('tags', $_GET) && $_GET['tags'] == 'true') {
+                $tagsDao = new \daos\Tags();
+                $tagsController = new \controllers\Tags();
+                $sync['tagshtml'] = $tagsController->renderTags($tagsDao->getWithUnread());
+            }
+            if (array_key_exists('sources', $_GET) && $_GET['sources'] == 'true') {
+                $sourcesDao = new \daos\Sources();
+                $sourcesController = new \controllers\Sources();
+                $sync['sourceshtml'] = $sourcesController->renderSources($sourcesDao->getWithUnread());
+            }
+
+            $wantItemsStatuses = array_key_exists('items_statuses', $_GET) && $_GET['items_statuses'] == 'true';
+            if ($wantItemsStatuses) {
+                $sync['items'] = $itemsDao->statuses($since->format(\DateTime::ATOM));
+            }
+        }
+        $this->view->jsonSuccess($sync);
+    }
 }
