@@ -1,42 +1,37 @@
-<?PHP
+<?php
 
 namespace controllers;
 
 /**
  * OPML loading and exporting controller
  *
- * @package    controllers
  * @copyright  Copyright (c) Tobias Zeising (http://www.aditu.de)
- * @license    GPLv3 (http://www.gnu.org/licenses/gpl-3.0.html)
+ * @license    GPLv3 (https://www.gnu.org/licenses/gpl-3.0.html)
  * @author     Michael Moore <stuporglue@gmail.com>
  * @author     Sean Rand <asanernd@gmail.com>
  */
-
 class Opml extends BaseController {
+    /** @var string Passed to opml.phtml */
+    private $msgclass = 'error';
 
-    /**
-     * Passed to opml.phtml
-     * @var String
-     */
-    private $msgclass = 'error'; 
-    
-    /**
-     * Passed to opml.phtml
-     * @var String
-     */
+    /** @var string Passed to opml.phtml */
     private $msg;
 
+    /** @var array Sources that have been imported from the OPML file */
+    private $imported = [];
+
+    /** @var \helpers\SpoutLoader */
+    private $spoutLoader;
+
+    public function __construct() {
+        parent::__construct();
+
+        $this->spoutLoader = new \helpers\SpoutLoader($this);
+    }
+
     /**
-    * Sources that have been imported from the OPML file
-    * @var Array
-    */
-    private $imported = array();
-
-
-    /** 
      * Shows a simple html form
      * html
-     *
      */
     public function show() {
         $this->needsLoggedIn();
@@ -46,8 +41,7 @@ class Opml extends BaseController {
         $this->view->msgclass = $this->msgclass;
         echo $this->view->render('templates/opml.phtml');
     }
-    
-    
+
     /**
      * Add an OPML to the user's subscriptions
      * html
@@ -60,16 +54,16 @@ class Opml extends BaseController {
         try {
             $opml = $_FILES['opml'];
             if ($opml['error'] == UPLOAD_ERR_NO_FILE) {
-                throw new \Exception("No file uploaded!");
+                throw new \Exception('No file uploaded!');
             }
-            if (! in_array($opml['type'], array('application/xml', 'text/xml', 'text/x-opml+xml', 'text/x-opml'))) {
-                throw new \Exception("Unsupported file type: " . $opml['type']);
+            if (!in_array($opml['type'], ['application/xml', 'text/xml', 'text/x-opml+xml', 'text/x-opml'])) {
+                throw new \Exception('Unsupported file type: ' . $opml['type']);
             }
 
             $this->sourcesDao = new \daos\Sources();
             $this->tagsDao = new \daos\Tags();
 
-            \F3::get('logger')->log('start OPML import ', \DEBUG);
+            \F3::get('logger')->debug('start OPML import ');
 
             $subs = simplexml_load_file($opml['tmp_name']);
             $errors = $this->processGroup($subs->body);
@@ -77,30 +71,29 @@ class Opml extends BaseController {
             // cleanup tags
             $this->tagsDao->cleanup($this->sourcesDao->getAllTags());
 
-            \F3::get('logger')->log('finished OPML import ', \DEBUG);
+            \F3::get('logger')->debug('finished OPML import ');
 
             // show errors
             if (count($errors) > 0) {
-                $this->msg = "The following feeds could not be imported:<br>";
-                $this->msg .= implode("<br>", $errors);
+                $this->msg = 'The following feeds could not be imported:<br>';
+                $this->msg .= implode('<br>', $errors);
                 $this->show();
-                
+
             // On success bring them back to their subscription list
             } else {
                 $amount = count($this->imported);
-                $this->msg = "Success! " . $amount . " feed" . ($amount!=1?"s have":" has") . " been imported.<br />" .
-                             "You might want to <a href='update'>update now</a> or <a href='./'>view your feeds</a>.";
+                $this->msg = 'Success! ' . $amount . ' feed' . ($amount != 1 ? 's have' : ' has') . ' been imported.<br>' .
+                    'You might want to <a href="update">update now</a> or <a href="./">view your feeds</a>.';
                 $this->msgclass = 'success';
                 $this->show();
             }
         } catch (\Exception $e) {
-            $this->msg = "</p>There was a problem importing your OPML file: <p>";
+            $this->msg = '</p>There was a problem importing your OPML file: <p>';
             $this->msg .= $e->getMessage();
             $this->show();
         }
     }
-    
-    
+
     /**
      * Process a group of outlines
      *
@@ -110,27 +103,28 @@ class Opml extends BaseController {
      * @note We use non-rss outline's text as tags
      * @note Reads outline elements from both the default and selfoss namespace
      */
-    private function processGroup($xml, $tags = Array()) {
-        $errors = Array();
+    private function processGroup($xml, $tags = []) {
+        $errors = [];
 
         $xml->registerXPathNamespace('selfoss', 'http://selfoss.aditu.de/');
 
         // tags are the words of the outline parent
-        $title = (string)$xml->attributes(null)->title;
-        if ($title!=null && $title!='/') {
+        $title = (string) $xml->attributes(null)->title;
+        if ($title != null && $title != '/') {
             $tags[] = $title;
             // for new tags, try to import tag color, otherwise use random color
             if (!$this->tagsDao->hasTag($title)) {
-                $tagColor = (string)$xml->attributes('selfoss', true)->color;
-                if ($tagColor != null)
+                $tagColor = (string) $xml->attributes('selfoss', true)->color;
+                if ($tagColor != null) {
                     $this->tagsDao->saveTagColor($title, $tagColor);
-                else
+                } else {
                     $this->tagsDao->autocolorTag($title);
+                }
             }
         }
 
         // parse outline items from the default and selfoss namespaces
-        foreach ($xml->xpath("outline|selfoss:outline") as $outline) {
+        foreach ($xml->xpath('outline|selfoss:outline') as $outline) {
             if (count($outline->children()) + count($outline->children('selfoss', true)) > 0) {
                 // outline element has children, recurse into it
                 $ret = $this->processGroup($outline, $tags);
@@ -142,16 +136,17 @@ class Opml extends BaseController {
                 }
             }
         }
+
         return $errors;
     }
-    
-    
+
     /**
      * Add new feed subscription
      *
-     * @return true on success or item title on error
      * @param $xml xml feed entry for item
      * @param $tags of the entry
+     *
+     * @return true on success or item title on error
      */
     private function addSubscription($xml, $tags) {
         // OPML Required attributes: text, xmlUrl, type
@@ -162,39 +157,40 @@ class Opml extends BaseController {
         $nsattrs = $xml->attributes('selfoss', true);
 
         // description
-        $title = (string)$attrs->text;
+        $title = (string) $attrs->text;
         if ($title == null) {
-            $title = (string)$attrs->title;
+            $title = (string) $attrs->title;
         }
-        
+
         // RSS URL
-        $data['url'] = (string)$attrs->xmlUrl;
+        $data['url'] = (string) $attrs->xmlUrl;
 
         // set spout for new item
         if ($nsattrs->spout || $nsattrs->params) {
             if (!($nsattrs->spout && $nsattrs->params)) {
-                \F3::get('logger')->log('OPML import: failed to import      "' . $title . '"', \WARNING);
-                \F3::get('logger')->log('                                     missing attribute ' .
-                                        ($nsattrs->spout ? '"selfoss:params"' : '"selfoss:spout"'), \DEBUG);
+                \F3::get('logger')->warning("OPML import: failed to import '$title'");
+                $missingAttr = $nsattrs->spout ? '"selfoss:params"' : '"selfoss:spout"';
+                \F3::get('logger')->debug("Missing attribute: $missingAttr");
+
                 return $title;
             }
-            $spout = (string)$nsattrs->spout;
-            $data = json_decode(html_entity_decode((string)$nsattrs->params), true);
-        } else if (in_array((string)$attrs->type, array('rss', 'atom'))) {
+            $spout = (string) $nsattrs->spout;
+            $data = json_decode(html_entity_decode((string) $nsattrs->params), true);
+        } elseif (in_array((string) $attrs->type, ['rss', 'atom'])) {
             $spout = 'spouts\rss\feed';
         } else {
-            \F3::get('logger')->log('OPML import: failed to import      "' . $title . '"', \WARNING);
-            \F3::get('logger')->log('                                     invalid type "' . (string)$attrs->type .
-                                    '": only "rss" and "atom" are supported', \DEBUG);
+            \F3::get('logger')->warning("OPML import: failed to import '$title'");
+            \F3::get('logger')->debug("Invalid type '$attrs->type': only 'rss' and 'atom' are supported");
+
             return $title;
         }
 
         // validate new item
         $validation = @$this->sourcesDao->validate($title, $spout, $data);
         if ($validation !== true) {
-            \F3::get('logger')->log('OPML import: failed to import      "' . $title . '"', \WARNING);
-            foreach ($validation as $id => $param)
-                \F3::get('logger')->log('                                     ' . $id . ': ' . $param, \DEBUG);
+            \F3::get('logger')->warning("OPML import: failed to import '$title'");
+            \F3::get('logger')->debug('Invalid source', $validation);
+
             return $title;
         }
 
@@ -204,23 +200,22 @@ class Opml extends BaseController {
             $this->imported[$hash]['tags'] = array_unique(array_merge($this->imported[$hash]['tags'], $tags));
             $tags = implode(',', $this->imported[$hash]['tags']);
             $this->sourcesDao->edit($this->imported[$hash]['id'], $title, $tags, '', $spout, $data);
-            \F3::get('logger')->log('  OPML import: updated tags for      "' . $title . '"', \DEBUG);
+            \F3::get('logger')->debug("OPML import: updated tags for '$title'");
         } elseif ($id = $this->sourcesDao->checkIfExists($title, $spout, $data)) {
             $tags = array_unique(array_merge($this->sourcesDao->getTags($id), $tags));
             $this->sourcesDao->edit($id, $title, implode(',', $tags), '', $spout, $data);
-            $this->imported[$hash] = Array('id' => $id, 'tags' => $tags);
-            \F3::get('logger')->log('  OPML import: updated tags for  "' . $title . '"', \DEBUG);
+            $this->imported[$hash] = ['id' => $id, 'tags' => $tags];
+            \F3::get('logger')->debug("OPML import: updated tags for '$title'");
         } else {
             $id = $this->sourcesDao->add($title, implode(',', $tags), '', $spout, $data);
-            $this->imported[$hash] = Array('id' => $id, 'tags' => $tags);
-            \F3::get('logger')->log('  OPML import: successfully imported "' . $title . '"', \DEBUG);
+            $this->imported[$hash] = ['id' => $id, 'tags' => $tags];
+            \F3::get('logger')->debug("OPML import: successfully imported '$title'");
         }
 
         // success
         return true;
     }
 
-
     /**
      * Generate an OPML outline element from a source
      *
@@ -230,13 +225,14 @@ class Opml extends BaseController {
     private function writeSource($source) {
         // retrieve the feed url of the source
         $params = json_decode(html_entity_decode($source['params']), true);
-        $feedUrl = $source['spout_obj']->getXmlUrl($params);
+        $feedUrl = $this->spoutLoader->get($source['spout'])->getXmlUrl($params);
 
         // if the spout doesn't return a feed url, the source isn't an RSS feed
-        if ($feedUrl !== false)
+        if ($feedUrl !== false) {
             $this->writer->startElement('outline');
-        else
+        } else {
             $this->writer->startElementNS('selfoss', 'outline', null);
+        }
 
         $this->writer->writeAttribute('title', $source['title']);
         $this->writer->writeAttribute('text', $source['title']);
@@ -251,10 +247,9 @@ class Opml extends BaseController {
         $this->writer->writeAttributeNS('selfoss', 'params', null, html_entity_decode($source['params']));
 
         $this->writer->endElement();  // outline
-        \F3::get('logger')->log("done exporting source ".$source['title'], \DEBUG);
+        \F3::get('logger')->debug('done exporting source ' . $source['title']);
     }
 
-
     /**
      * Export user's subscriptions to OPML file
      *
@@ -266,7 +261,7 @@ class Opml extends BaseController {
         $this->sourcesDao = new \daos\Sources();
         $this->tagsDao = new \daos\Tags();
 
-        \F3::get('logger')->log('start OPML export', \DEBUG);
+        \F3::get('logger')->debug('start OPML export');
         $this->writer = new \XMLWriter();
         $this->writer->openMemory();
         $this->writer->setIndent(1);
@@ -284,37 +279,38 @@ class Opml extends BaseController {
         $this->writer->writeAttribute('version', '1.0');
         $this->writer->writeAttribute('createdOn', date('r'));
         $this->writer->endElement();  // meta
-        \F3::get('logger')->log('OPML export: finished writing meta', \DEBUG);
+        \F3::get('logger')->debug('OPML export: finished writing meta');
 
         $this->writer->startElement('head');
         $user = \F3::get('username');
-        $this->writer->writeElement('title', ($user?$user.'\'s':'My') . ' subscriptions in selfoss');
+        $this->writer->writeElement('title', ($user ? $user . '\'s' : 'My') . ' subscriptions in selfoss');
         $this->writer->endElement();  // head
-        \F3::get('logger')->log('OPML export: finished writing head', \DEBUG);
+        \F3::get('logger')->debug('OPML export: finished writing head');
 
         $this->writer->startElement('body');
 
         // create tree structure for tagged and untagged sources
-        $sources = array('tagged'=>array(), 'untagged'=>array());
+        $sources = ['tagged' => [], 'untagged' => []];
         foreach ($this->sourcesDao->get() as $source) {
             if ($source['tags']) {
-                foreach (explode(',', $source['tags']) as $tag)
+                foreach (explode(',', $source['tags']) as $tag) {
                     $sources['tagged'][$tag][] = $source;
+                }
             } else {
                 $sources['untagged'][] = $source;
             }
         }
 
         // create associative array with tag names as keys, colors as values
-        $tagColors = array();
+        $tagColors = [];
         foreach ($this->tagsDao->get() as $key => $tag) {
-            \F3::get('logger')->log("OPML export: tag ".$tag['tag']." has color ".$tag['color'], \DEBUG);
+            \F3::get('logger')->debug('OPML export: tag ' . $tag['tag'] . ' has color ' . $tag['color']);
             $tagColors[$tag['tag']] = $tag['color'];
         }
 
         // generate outline elements for all sources
         foreach ($sources['tagged'] as $tag => $children) {
-            \F3::get('logger')->log("OPML export: exporting tag $tag sources", \DEBUG);
+            \F3::get('logger')->debug("OPML export: exporting tag $tag sources");
             $this->writer->startElement('outline');
             $this->writer->writeAttribute('title', $tag);
             $this->writer->writeAttribute('text', $tag);
@@ -328,7 +324,7 @@ class Opml extends BaseController {
             $this->writer->endElement();  // outline
         }
 
-        \F3::get('logger')->log("OPML export: exporting untagged sources", \DEBUG);
+        \F3::get('logger')->debug('OPML export: exporting untagged sources');
         foreach ($sources['untagged'] as $key => $source) {
             $this->writeSource($source);
         }
@@ -336,7 +332,7 @@ class Opml extends BaseController {
         $this->writer->endElement();  // body
 
         $this->writer->endDocument();
-        \F3::get('logger')->log('finished OPML export', \DEBUG);
+        \F3::get('logger')->debug('finished OPML export');
 
         // save content as file and suggest file name
         header('Content-Disposition: attachment; filename="selfoss-subscriptions.xml"');
