@@ -1,17 +1,15 @@
-<?PHP
+<?php
 
 namespace controllers;
 
 /**
  * Controller for tag access
  *
- * @package    controllers
  * @copyright  Copyright (c) Tobias Zeising (http://www.aditu.de)
- * @license    GPLv3 (http://www.gnu.org/licenses/gpl-3.0.html)
+ * @license    GPLv3 (https://www.gnu.org/licenses/gpl-3.0.html)
  * @author     Tobias Zeising <tobias.zeising@aditu.de>
  */
 class Tags extends BaseController {
-
     /**
      * returns all tags
      * html
@@ -23,8 +21,7 @@ class Tags extends BaseController {
 
         echo $this->tagsListAsString();
     }
-    
-    
+
     /**
      * returns all tags
      * html
@@ -33,10 +30,10 @@ class Tags extends BaseController {
      */
     public function tagsListAsString() {
         $tagsDao = new \daos\Tags();
+
         return $this->renderTags($tagsDao->getWithUnread());
     }
-    
-    
+
     /**
      * returns all tags
      * html
@@ -44,18 +41,17 @@ class Tags extends BaseController {
      * @return void
      */
     public function renderTags($tags) {
-        $html = "";
-        foreach($tags as $tag) {
+        $html = '';
+        foreach ($tags as $tag) {
             $this->view->tag = $tag['tag'];
             $this->view->color = $tag['color'];
             $this->view->unread = $tag['unread'];
             $html .= $this->view->render('templates/tag.phtml');
         }
-        
+
         return $html;
     }
-    
-    
+
     /**
      * set tag color
      *
@@ -63,26 +59,27 @@ class Tags extends BaseController {
      */
     public function color() {
         $this->needsLoggedIn();
-    
+
         // read data
-        parse_str(\F3::get('BODY'),$data);
-    
+        parse_str(\F3::get('BODY'), $data);
+
         $tag = $data['tag'];
         $color = $data['color'];
-        
-        if(!isset($tag) || strlen(trim($tag))==0)
+
+        if (!isset($tag) || strlen(trim($tag)) == 0) {
             $this->view->error('invalid or no tag given');
-        if(!isset($color) || strlen(trim($color))==0)
+        }
+        if (!isset($color) || strlen(trim($color)) == 0) {
             $this->view->error('invalid or no color given');
-            
+        }
+
         $tagsDao = new \daos\Tags();
         $tagsDao->saveTagColor($tag, $color);
-        $this->view->jsonSuccess(array(
+        $this->view->jsonSuccess([
             'success' => true
-        ));
+        ]);
     }
-    
-    
+
     /**
      * returns all tags
      * html
