@@ -1,25 +1,18 @@
-<?PHP
+<?php
 
 namespace daos\mysql;
-    
+
 /**
  * Base class for database access -- mysql
  *
- * @package    daos
  * @copyright  Copyright (c) Tobias Zeising (http://www.aditu.de)
- * @license    GPLv3 (http://www.gnu.org/licenses/gpl-3.0.html)
+ * @license    GPLv3 (https://www.gnu.org/licenses/gpl-3.0.html)
  * @author     Tobias Zeising <tobias.zeising@aditu.de>
  */
 class Database {
+    /** @var bool indicates whether database connection was initialized */
+    private static $initialized = false;
 
-    /**
-     * indicates whether database connection was
-     * initialized
-     * @var bool
-     */
-    static private $initialized = false;
-
-    
     /**
      * establish connection and
      * create undefined tables
@@ -27,24 +20,37 @@ class Database {
      * @return void
      */
     public function __construct() {
-        if(self::$initialized===false && \F3::get('db_type')=="mysql") {
-            \F3::get('logger')->log("Establish database connection", \DEBUG);
+        if (self::$initialized === false && \F3::get('db_type') == 'mysql') {
+            $host = \F3::get('db_host');
+            $port = \F3::get('db_port');
+            $database = \F3::get('db_database');
+
+            if ($port) {
+                $dsn = "mysql:host=$host; port=$port; dbname=$database";
+            } else {
+                $dsn = "mysql:host=$host; dbname=$database";
+            }
+
+            \F3::get('logger')->debug('Establish database connection');
             \F3::set('db', new \DB\SQL(
-                'mysql:host=' . \F3::get('db_host') . ';port=' . \F3::get('db_port') . ';dbname='.\F3::get('db_database'),
+                $dsn,
                 \F3::get('db_username'),
-                \F3::get('db_password')
+                \F3::get('db_password'),
+                [\PDO::MYSQL_ATTR_INIT_COMMAND => 'SET NAMES utf8mb4;']
             ));
-            
+
             // create tables if necessary
             $result = @\F3::get('db')->exec('SHOW TABLES');
-            $tables = array();
-            foreach($result as $table)
-                foreach($table as $key=>$value)
+            $tables = [];
+            foreach ($result as $table) {
+                foreach ($table as $key => $value) {
                     $tables[] = $value;
-            
-            if(!in_array(\F3::get('db_prefix').'items', $tables)) {
+                }
+            }
+
+            if (!in_array(\F3::get('db_prefix') . 'items', $tables)) {
                 \F3::get('db')->exec('
-                    CREATE TABLE '.\F3::get('db_prefix').'items (
+                    CREATE TABLE ' . \F3::get('db_prefix') . 'items (
                         id INT NOT NULL AUTO_INCREMENT PRIMARY KEY ,
                         datetime DATETIME NOT NULL ,
                         title TEXT NOT NULL ,
@@ -56,10 +62,10 @@ class Database {
                         source INT NOT NULL ,
                         uid VARCHAR(255) NOT NULL,
                         link TEXT NOT NULL,
-                        updatetime DATETIME NOT NULL DEFAULT CURRENT_TIMESTAMP,
+                        updatetime DATETIME NOT NULL,
                         author VARCHAR(255),
                         INDEX (source)
-                    ) ENGINE = InnoDB DEFAULT CHARSET=utf8;
+                    ) ENGINE = InnoDB DEFAULT CHARSET=utf8mb4;
                 ');
                 \F3::get('db')->exec('
                     CREATE TRIGGER insert_updatetime_trigger
@@ -76,11 +82,11 @@ class Database {
                         END;
                 ');
             }
-            
+
             $isNewestSourcesTable = false;
-            if(!in_array(\F3::get('db_prefix').'sources', $tables)) {
+            if (!in_array(\F3::get('db_prefix') . 'sources', $tables)) {
                 \F3::get('db')->exec('
-                    CREATE TABLE '.\F3::get('db_prefix').'sources (
+                    CREATE TABLE ' . \F3::get('db_prefix') . 'sources (
                         id INT NOT NULL AUTO_INCREMENT PRIMARY KEY ,
                         title TEXT NOT NULL ,
                         tags TEXT,
@@ -90,51 +96,50 @@ class Database {
                         error TEXT,
                         lastupdate INT,
                 		lastentry INT
-                    ) ENGINE = InnoDB DEFAULT CHARSET=utf8;
+                    ) ENGINE = InnoDB DEFAULT CHARSET=utf8mb4;
                 ');
                 $isNewestSourcesTable = true;
             }
-            
+
             // version 1 or new
-            if(!in_array(\F3::get('db_prefix').'version', $tables)) {
+            if (!in_array(\F3::get('db_prefix') . 'version', $tables)) {
                 \F3::get('db')->exec('
-                    CREATE TABLE '.\F3::get('db_prefix').'version (
+                    CREATE TABLE ' . \F3::get('db_prefix') . 'version (
                         version INT
-                    ) ENGINE = InnoDB DEFAULT CHARSET=utf8;
+                    ) ENGINE = InnoDB DEFAULT CHARSET=utf8mb4;
                 ');
-                
+
                 \F3::get('db')->exec('
-                    INSERT INTO '.\F3::get('db_prefix').'version (version) VALUES (8);
+                    INSERT INTO ' . \F3::get('db_prefix') . 'version (version) VALUES (8);
                 ');
-                
+
                 \F3::get('db')->exec('
-                    CREATE TABLE '.\F3::get('db_prefix').'tags (
+                    CREATE TABLE ' . \F3::get('db_prefix') . 'tags (
                         tag         TEXT NOT NULL,
                         color       VARCHAR(7) NOT NULL
-                    ) ENGINE = InnoDB DEFAULT CHARSET=utf8;
+                    ) ENGINE = InnoDB DEFAULT CHARSET=utf8mb4;
                 ');
-                
-                if($isNewestSourcesTable===false) {
+
+                if ($isNewestSourcesTable === false) {
                     \F3::get('db')->exec('
-                        ALTER TABLE '.\F3::get('db_prefix').'sources ADD tags TEXT;
+                        ALTER TABLE ' . \F3::get('db_prefix') . 'sources ADD tags TEXT;
                     ');
                 }
-            }
-            else{
-                $version = @\F3::get('db')->exec('SELECT version FROM '.\F3::get('db_prefix').'version ORDER BY version DESC LIMIT 0, 1');
+            } else {
+                $version = @\F3::get('db')->exec('SELECT version FROM ' . \F3::get('db_prefix') . 'version ORDER BY version DESC LIMIT 0, 1');
                 $version = $version[0]['version'];
-                
-                if(strnatcmp($version, "3") < 0){
+
+                if (strnatcmp($version, '3') < 0) {
                     \F3::get('db')->exec('
-                        ALTER TABLE '.\F3::get('db_prefix').'sources ADD lastupdate INT;
+                        ALTER TABLE ' . \F3::get('db_prefix') . 'sources ADD lastupdate INT;
                     ');
                     \F3::get('db')->exec('
-                        INSERT INTO '.\F3::get('db_prefix').'version (version) VALUES (3);
+                        INSERT INTO ' . \F3::get('db_prefix') . 'version (version) VALUES (3);
                     ');
                 }
-                if(strnatcmp($version, "4") < 0){
+                if (strnatcmp($version, '4') < 0) {
                     \F3::get('db')->exec('
-                        ALTER TABLE '.\F3::get('db_prefix').'items ADD updatetime DATETIME;
+                        ALTER TABLE ' . \F3::get('db_prefix') . 'items ADD updatetime DATETIME;
                     ');
                     \F3::get('db')->exec('
                         CREATE TRIGGER insert_updatetime_trigger
@@ -151,46 +156,55 @@ class Database {
                             END;
                     ');
                     \F3::get('db')->exec('
-                        INSERT INTO '.\F3::get('db_prefix').'version (version) VALUES (4);
+                        INSERT INTO ' . \F3::get('db_prefix') . 'version (version) VALUES (4);
                     ');
                 }
-                if(strnatcmp($version, "5") < 0){
+                if (strnatcmp($version, '5') < 0) {
                     \F3::get('db')->exec('
-                        ALTER TABLE '.\F3::get('db_prefix').'items ADD author VARCHAR(255);
+                        ALTER TABLE ' . \F3::get('db_prefix') . 'items ADD author VARCHAR(255);
                     ');
                     \F3::get('db')->exec('
-                        INSERT INTO '.\F3::get('db_prefix').'version (version) VALUES (5);
+                        INSERT INTO ' . \F3::get('db_prefix') . 'version (version) VALUES (5);
                     ');
                 }
-                if(strnatcmp($version, "6") < 0){
+                if (strnatcmp($version, '6') < 0) {
                     \F3::get('db')->exec('
-                        ALTER TABLE '.\F3::get('db_prefix').'sources ADD filter TEXT;
+                        ALTER TABLE ' . \F3::get('db_prefix') . 'sources ADD filter TEXT;
                     ');
                     \F3::get('db')->exec('
-                        INSERT INTO '.\F3::get('db_prefix').'version (version) VALUES (6);
+                        INSERT INTO ' . \F3::get('db_prefix') . 'version (version) VALUES (6);
                     ');
                 }
                 // Jump straight from v6 to v8 due to bug in previous version of the code
                 // in /daos/sqlite/Database.php which
                 // set the database version to "7" for initial installs.
-                if(strnatcmp($version, "8") < 0){
-                	\F3::get('db')->exec('
-                        ALTER TABLE '.\F3::get('db_prefix').'sources ADD lastentry INT;
+                if (strnatcmp($version, '8') < 0) {
+                    \F3::get('db')->exec('
+                        ALTER TABLE ' . \F3::get('db_prefix') . 'sources ADD lastentry INT;
                     ');
-                	\F3::get('db')->exec('
-                        INSERT INTO '.\F3::get('db_prefix').'version (version) VALUES (8);
+                    \F3::get('db')->exec('
+                        INSERT INTO ' . \F3::get('db_prefix') . 'version (version) VALUES (8);
                     ');
                 }
-				if(strnatcmp($version, "9") < 0) {
-					\F3::get('db')->exec('
-                        ALTER TABLE '.\F3::get('db_prefix').'items ADD shared BOOL;
+                if (strnatcmp($version, '9') < 0) {
+                    \F3::get('db')->exec('
+                        ALTER TABLE ' . \F3::get('db_prefix') . 'items ADD shared BOOL;
                     ');
-					\F3::get('db')->exec('
-                        INSERT INTO version (version) VALUES (9);
+                    \F3::get('db')->exec('
+                        INSERT INTO ' . \F3::get('db_prefix') . 'version (version) VALUES (9);
                     ');
-				}
+                }
+                if (strnatcmp($version, '10') < 0) {
+                    \F3::get('db')->exec([
+                        'ALTER TABLE `' . \F3::get('db_prefix') . 'items` CONVERT TO CHARACTER SET utf8mb4;',
+                        'ALTER TABLE `' . \F3::get('db_prefix') . 'sources` CONVERT TO CHARACTER SET utf8mb4;',
+                        'ALTER TABLE `' . \F3::get('db_prefix') . 'tags` CONVERT TO CHARACTER SET utf8mb4;',
+                        'ALTER TABLE `' . \F3::get('db_prefix') . 'version` CONVERT TO CHARACTER SET utf8mb4;',
+                        'INSERT INTO `' . \F3::get('db_prefix') . 'version` (version) VALUES (10);'
+                    ]);
+                }
             }
-            
+
             // just initialize once
             self::$initialized = true;
         }
@@ -198,8 +212,7 @@ class Database {
         $class = 'daos\\' . \F3::get('db_type') . '\\Statements';
         $this->stmt = new $class();
     }
-    
-    
+
     /**
      * optimize database by
      * database own optimize statement
@@ -207,6 +220,6 @@ class Database {
      * @return void
      */
     public function optimize() {
-        @\F3::get('db')->exec('OPTIMIZE TABLE `'.\F3::get('db_prefix').'sources`, `'.\F3::get('db_prefix').'items`');
+        @\F3::get('db')->exec('OPTIMIZE TABLE `' . \F3::get('db_prefix') . 'sources`, `' . \F3::get('db_prefix') . 'items`');
     }
 }
