@@ -1,41 +1,28 @@
-<?PHP 
+<?php
 
 namespace spouts\rss;
 
 /**
  * Spout for fetching an rss feed
  *
- * @package    spouts
- * @subpackage rss
  * @copyright  Copyright (c) Tobias Zeising (http://www.aditu.de)
- * @license    GPLv3 (http://www.gnu.org/licenses/gpl-3.0.html)
+ * @license    GPLv3 (https://www.gnu.org/licenses/gpl-3.0.html)
  * @author     Tobias Zeising <tobias.zeising@aditu.de>
  */
 class feed extends \spouts\spout {
-
-    /**
-     * name of source
-     *
-     * @var string
-     */
+    /** @var string name of source */
     public $name = 'RSS Feed';
-    
-    
-    /**
-     * description of this source type
-     *
-     * @var string
-     */
+
+    /** @var string description of this source type */
     public $description = 'An default RSS Feed as source';
-    
-    
+
     /**
      * config params
      * array of arrays with name, type, default value, required, validation type
      *
      * - Values for type: text, password, checkbox
      * - Values for validation: alpha, email, numeric, int, alnum, notempty
-     * 
+     *
      * e.g.
      * array(
      *   "id" => array(
@@ -50,101 +37,98 @@ class feed extends \spouts\spout {
      *
      * @var bool|mixed
      */
-    public $params = array(
-        "url" => array(
-            "title"      => "URL",
-            "type"       => "url",
-            "default"    => "",
-            "required"   => true,
-            "validation" => array("notempty")
-        )
-    );
-    
-    
-    /**
-     * current fetched items
-     *
-     * @var array|bool
-     */
+    public $params = [
+        'url' => [
+            'title' => 'URL',
+            'type' => 'url',
+            'default' => '',
+            'required' => true,
+            'validation' => ['notempty']
+        ]
+    ];
+
+    /** @var array|bool current fetched items */
     protected $items = false;
-    
-    
+
     //
     // Iterator Interface
     //
-    
+
     /**
      * reset iterator
      *
      * @return void
      */
     public function rewind() {
-        if($this->items!==false)
+        if ($this->items !== false) {
             reset($this->items);
+        }
     }
 
-    
     /**
      * receive current item
      *
      * @return SimplePie_Item current item
      */
     public function current() {
-        if($this->items!==false)
+        if ($this->items !== false) {
             return $this;
+        }
+
         return false;
     }
 
-    
     /**
      * receive key of current item
      *
      * @return mixed key of current item
      */
     public function key() {
-        if($this->items!==false)
+        if ($this->items !== false) {
             return key($this->items);
+        }
+
         return false;
     }
 
-    
     /**
      * select next item
      *
      * @return SimplePie_Item next item
      */
     public function next() {
-        if($this->items!==false)
+        if ($this->items !== false) {
             next($this->items);
+        }
+
         return $this;
     }
 
-    
     /**
      * end reached
      *
      * @return bool false if end reached
      */
     public function valid() {
-        if($this->items!==false)
+        if ($this->items !== false) {
             return current($this->items) !== false;
+        }
+
         return false;
     }
-    
-    
-    
+
     //
     // Source Methods
     //
-    
-    
+
     /**
      * loads content for given source
      * I supress all Warnings of SimplePie for ensuring
      * working plugin in PHP Strict mode
      *
-     * @return void
      * @param mixed $params the params of this source
+     *
+     * @return void
      */
     public function load($params) {
         // initialize simplepie feed loader
@@ -152,169 +136,180 @@ class feed extends \spouts\spout {
         @$this->feed->set_cache_location(\F3::get('cache'));
         @$this->feed->set_cache_duration(1800);
         @$this->feed->set_feed_url(htmlspecialchars_decode($params['url']));
-        @$this->feed->set_autodiscovery_level( SIMPLEPIE_LOCATOR_AUTODISCOVERY | SIMPLEPIE_LOCATOR_LOCAL_EXTENSION | SIMPLEPIE_LOCATOR_LOCAL_BODY);
-        $this->feed->set_useragent(\helpers\WebClient::getUserAgent(array('SimplePie/'.SIMPLEPIE_VERSION)));
-         
+        @$this->feed->set_autodiscovery_level(SIMPLEPIE_LOCATOR_AUTODISCOVERY | SIMPLEPIE_LOCATOR_LOCAL_EXTENSION | SIMPLEPIE_LOCATOR_LOCAL_BODY);
+        $this->feed->set_useragent(\helpers\WebClient::getUserAgent(['SimplePie/' . SIMPLEPIE_VERSION]));
+
         // fetch items
         @$this->feed->init();
-        
+
         // on error retry with force_feed
-        if(@$this->feed->error()) {
+        if (@$this->feed->error()) {
             @$this->feed->set_autodiscovery_level(SIMPLEPIE_LOCATOR_NONE);
             @$this->feed->force_feed(true);
             @$this->feed->init();
         }
-        
+
         // check for error
-        if(@$this->feed->error()) {
-            throw new \exception($this->feed->error());
+        if (@$this->feed->error()) {
+            throw new \Exception($this->feed->error());
         } else {
             // save fetched items
             $this->items = @$this->feed->get_items();
         }
-        
-        // return html url
-        $this->htmlUrl = @$this->feed->get_link();
-    }
 
+        // set html url
+        $this->htmlUrl = @$this->feed->get_link();
+
+        $this->spoutTitle = $this->feed->get_title();
+    }
 
     /**
      * returns the xml feed url for the source
      *
-     * @return string url as xml
      * @param mixed $params params for the source
+     *
+     * @return string url as xml
      */
     public function getXmlUrl($params) {
         return isset($params['url']) ? html_entity_decode($params['url']) : false;
     }
 
-
     /**
      * returns the global html url for the source
      *
      * @return string url as html
      */
     public function getHtmlUrl() {
-        if(isset($this->htmlUrl))
+        if (isset($this->htmlUrl)) {
             return $this->htmlUrl;
+        }
+
         return false;
     }
-    
-    
+
     /**
      * returns an unique id for this item
      *
      * @return string id as hash
      */
     public function getId() {
-        if($this->items!==false && $this->valid()) {
+        if ($this->items !== false && $this->valid()) {
             $id = @current($this->items)->get_id();
-            if(strlen($id)>255)
+            if (strlen($id) > 255) {
                 $id = md5($id);
+            }
+
             return $id;
         }
+
         return false;
     }
-    
-    
+
     /**
      * returns the current title as string
      *
      * @return string title
      */
     public function getTitle() {
-        if($this->items!==false && $this->valid())
+        if ($this->items !== false && $this->valid()) {
             return @current($this->items)->get_title();
+        }
+
         return false;
     }
-    
-    
+
     /**
      * returns the content of this item
      *
      * @return string content
      */
     public function getContent() {
-        if($this->items!==false && $this->valid())
+        if ($this->items !== false && $this->valid()) {
             return @current($this->items)->get_content();
+        }
+
         return false;
     }
-    
-    
+
     /**
      * returns the icon of this item
      *
      * @return string icon url
      */
     public function getIcon() {
-        if(isset($this->faviconUrl))
+        if (isset($this->faviconUrl)) {
             return $this->faviconUrl;
-        
+        }
+
         $this->faviconUrl = false;
         $imageHelper = $this->getImageHelper();
         $htmlUrl = $this->getHtmlUrl();
-        if($htmlUrl && $imageHelper->fetchFavicon($htmlUrl, true)){
+        if ($htmlUrl && $imageHelper->fetchFavicon($htmlUrl, true)) {
             $this->faviconUrl = $imageHelper->getFaviconUrl();
-            \F3::get('logger')->log('icon: using feed homepage favicon: ' . $this->faviconUrl, \DEBUG);
-        }else{
+            \F3::get('logger')->debug('icon: using feed homepage favicon: ' . $this->faviconUrl);
+        } else {
             $feedLogoUrl = $this->feed->get_image_url();
-            if( $feedLogoUrl && $imageHelper->fetchFavicon($feedLogoUrl) ){
+            if ($feedLogoUrl && $imageHelper->fetchFavicon($feedLogoUrl)) {
                 $this->faviconUrl = $imageHelper->getFaviconUrl();
-                \F3::get('logger')->log('icon: using feed logo: ' . $this->faviconUrl, \DEBUG);
-           }
+                \F3::get('logger')->debug('icon: using feed logo: ' . $this->faviconUrl);
+            }
         }
+
         return $this->faviconUrl;
     }
-    
-    
+
     /**
      * returns the link of this item
      *
      * @return string link
      */
     public function getLink() {
-        if($this->items!==false && $this->valid()) {
+        if ($this->items !== false && $this->valid()) {
             $link = @current($this->items)->get_link();
+
             return $link;
         }
+
         return false;
     }
-    
-    
+
     /**
      * returns the date of this item
      *
      * @return string date
      */
     public function getDate() {
-        if($this->items!==false && $this->valid())
+        if ($this->items !== false && $this->valid()) {
             $date = @current($this->items)->get_date('Y-m-d H:i:s');
-        if(strlen($date)==0)
+        }
+        if (strlen($date) == 0) {
             $date = date('Y-m-d H:i:s');
+        }
+
         return $date;
     }
 
-
     /**
      * returns the author of this item
+     *
      * @return string author
      */
     public function getAuthor() {
-        if($this->items!==false && $this->valid()) {
+        if ($this->items !== false && $this->valid()) {
             $author = @current($this->items)->get_author();
-            if(isset($author)) {
+            if (isset($author)) {
                 $name = $author->get_name();
-                if(isset($name)) {
+                if (isset($name)) {
                     return $name;
                 } else {
                     return $author->get_email();
                 }
             }
         }
+
         return null;
     }
 
-    
     /**
      * destroy the plugin (prevent memory issues)
      */
