@@ -1,74 +1,64 @@
-<?PHP 
+<?php
 
 namespace spouts\rss;
 
 /**
  * Spout for fetching images from given rss feed
  *
- * @package    spouts
- * @subpackage rss
  * @copyright  Copyright (c) Tobias Zeising (http://www.aditu.de)
- * @license    GPLv3 (http://www.gnu.org/licenses/gpl-3.0.html)
+ * @license    GPLv3 (https://www.gnu.org/licenses/gpl-3.0.html)
  * @author     Tobias Zeising <tobias.zeising@aditu.de>
  */
 class images extends feed {
-
-    /**
-     * name of spout
-     *
-     * @var string
-     */
+    /** @var string name of spout */
     public $name = 'RSS Feed Images';
-    
-    
-    /**
-     * description of this source type
-     *
-     * @var string
-     */
+
+    /** @var string description of this source type */
     public $description = 'Fetching images from given rss feed';
-    
-    
+
     /**
      * returns the thumbnail of this item (for multimedia feeds)
      *
      * @return mixed thumbnail data
      */
     public function getThumbnail() {
-        if($this->items===false || $this->valid()===false)
-            return "";
-    
+        if ($this->items === false || $this->valid() === false) {
+            return '';
+        }
+
         $item = current($this->items);
-        
+
         // search enclosures (media tags)
-        if(count(@$item->get_enclosures()) > 0) {
-        
+        if (count(@$item->get_enclosures()) > 0) {
             // thumbnail given?
-            if(@$item->get_enclosure(0)->get_thumbnail())
+            if (@$item->get_enclosure(0)->get_thumbnail()) {
                 return @$item->get_enclosure(0)->get_thumbnail();
-            
+            }
+
             // link given?
-            elseif(@$item->get_enclosure(0)->get_link())
+            elseif (@$item->get_enclosure(0)->get_link()) {
                 return @$item->get_enclosure(0)->get_link();
-        
+            }
+
         // no enclosures: search image link in content
         } else {
-            
-            $image = $this->getImage(@$item->get_content());  
-            if($image!==false)
+            $image = $this->getImage(@$item->get_content());
+            if ($image !== false) {
                 return $image;
+            }
         }
-        
-        return "";
+
+        return '';
     }
-    
-   
+
     /**
      * taken from: http://zytzagoo.net/blog/2008/01/23/extracting-images-from-html-using-regular-expressions/
      * Searches for the first occurence of an html <img> element in a string
      * and extracts the src if it finds it. Returns boolean false in case an
      * <img> element is not found.
+     *
      * @param    string  $str    An HTML string
+     *
      * @return   mixed           The contents of the src attribute in the
      *                           found <img> or boolean false if no <img>
      *                           is found
@@ -88,5 +78,4 @@ class images extends feed {
             return false;
         }
     }
-        
 }
